@@ -202,6 +202,7 @@ RECEIPT_FORMATTERS = {
     'logsBloom': to_hexbytes(256),
     'from': apply_formatter_if(is_not_null, to_checksum_address),
     'to': apply_formatter_if(is_address, to_checksum_address),
+    'effectiveGasPrice': to_integer_if_hex,
 }
 
 
@@ -277,6 +278,16 @@ transaction_pool_inspect_formatter = apply_formatters_to_dict(
     TRANSACTION_POOL_INSPECT_FORMATTERS
 )
 
+FEE_HISTORY_FORMATTERS = {
+    'baseFeePerGas': apply_formatter_to_array(to_integer_if_hex),
+    'gasUsedRatio': apply_formatter_if(is_not_null, apply_formatter_to_array(float)),
+    'oldestBlock': to_integer_if_hex,
+    'reward': apply_formatter_if(is_not_null, apply_formatter_to_array(
+        apply_formatter_to_array(to_integer_if_hex))),
+}
+
+fee_history_formatter = apply_formatters_to_dict(FEE_HISTORY_FORMATTERS)
+
 STORAGE_PROOF_FORMATTERS = {
     'key': HexBytes,
     'value': HexBytes,
@@ -381,6 +392,10 @@ geth_wallets_formatter = apply_formatters_to_dict(GETH_WALLETS_FORMATTER)
 
 PYTHONIC_REQUEST_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     # Eth
+    RPC.eth_feeHistory: compose(
+        apply_formatter_at_index(to_hex_if_integer, 0),
+        apply_formatter_at_index(to_hex_if_integer, 1)
+    ),
     RPC.eth_getBalance: apply_formatter_at_index(to_hex_if_integer, 1),
     RPC.eth_getBlockByNumber: apply_formatter_at_index(to_hex_if_integer, 0),
     RPC.eth_getBlockTransactionCountByNumber: apply_formatter_at_index(
@@ -411,6 +426,7 @@ PYTHONIC_REQUEST_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
         (is_length(2), estimate_gas_with_block_id),
     )),
     RPC.eth_sendTransaction: apply_formatter_at_index(transaction_param_formatter, 0),
+    RPC.eth_signTransaction: apply_formatter_at_index(transaction_param_formatter, 0),
     RPC.eth_getProof: apply_formatter_at_index(to_hex_if_integer, 2),
     # personal
     RPC.personal_importRawKey: apply_formatter_at_index(
@@ -439,6 +455,8 @@ PYTHONIC_RESULT_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     RPC.eth_coinbase: to_checksum_address,
     RPC.eth_call: HexBytes,
     RPC.eth_estimateGas: to_integer_if_hex,
+    RPC.eth_feeHistory: fee_history_formatter,
+    RPC.eth_maxPriorityFeePerGas: to_integer_if_hex,
     RPC.eth_gasPrice: to_integer_if_hex,
     RPC.eth_getBalance: to_integer_if_hex,
     RPC.eth_getBlockByHash: apply_formatter_if(is_not_null, block_formatter),
@@ -450,6 +468,7 @@ PYTHONIC_RESULT_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     RPC.eth_getFilterLogs: filter_result_formatter,
     RPC.eth_getLogs: filter_result_formatter,
     RPC.eth_getProof: apply_formatter_if(is_not_null, proof_formatter),
+    RPC.eth_getRawTransactionByHash: HexBytes,
     RPC.eth_getStorageAt: HexBytes,
     RPC.eth_getTransactionByBlockHashAndIndex: apply_formatter_if(
         is_not_null,
@@ -657,6 +676,7 @@ NULL_RESULT_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     RPC.eth_getTransactionByBlockHashAndIndex: raise_transaction_not_found_with_index,
     RPC.eth_getTransactionByBlockNumberAndIndex: raise_transaction_not_found_with_index,
     RPC.eth_getTransactionReceipt: raise_transaction_not_found,
+    RPC.eth_getRawTransactionByHash: raise_transaction_not_found,
 }
 
 
